@@ -1,4 +1,4 @@
-# coding: utf-8
+# encoding: utf-8
 """
 The *pathspec* package provides pattern matching for file paths. So far
 this only includes gitignore style pattern matching.
@@ -13,13 +13,14 @@ __created__ = "2013-10-12"
 __credits__ = [
 	"dahlia <https://github.com/dahlia>",
 	"highb <https://github.com/highb>",
+	"029xue <https://github.com/029xue>",
 ]
 __email__ = "cpburnz@gmail.com"
 __license__ = "MPL 2.0"
 __project__ = "pathspec"
 __status__ = "Development"
-__updated__ = "2014-09-17"
-__version__ = "0.3.1"
+__updated__ = "2014-11-08"
+__version__ = "0.3.2"
 
 from .gitignore import GitIgnorePattern
 from .pathspec import PathSpec
